using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Infragistics.Win.Misc;
using Infragistics.Win.Misc.UltraWinNavigationBar;
using Infragistics.Win.UltraWinListView;

namespace FileSystemNavigator
{
    public partial class FileSystemNavigator : Form
    {
        public FileSystemNavigator()
        {
            InitializeComponent();

            this.InitializeUI( "C:\\Program Files\\Infragistics" );
        }

        private void InitializeUI( string rootLocation )
        {
            if ( Directory.Exists(rootLocation) == false )
                throw new Exception( string.Format("'{0}' is not a valid path.", rootLocation) );

            //  Assign a DirectoryInfo for the specified path to the Tag property for future reference
            DirectoryInfo rootDirectoryInfo = new DirectoryInfo( rootLocation );
            this.unbFolders.RootLocation.Tag = rootDirectoryInfo;
            this.unbFolders.RootLocation.DisplayText = rootDirectoryInfo.Name;
            this.unbFolders.RootLocation.ToolTipText = rootLocation;

            //  Handle the InitializeLocations event
            this.unbFolders.InitializeLocations += new InitializeLocationsHandler(unbFolders_InitializeLocations);

            //  Handle the SelectedLocationChanged event
            this.unbFolders.SelectedLocationChanged += new SelectedLocationChangedHandler(unbFolders_SelectedLocationChanged);
        }

        private void unbFolders_SelectedLocationChanged(object sender, SelectedLocationChangedEventArgs e)
        {
            //  Populate the ListView with the files in the currently selected folder
            this.lvwFiles.Items.Clear();

            DirectoryInfo directory = e.SelectedLocation.Tag as DirectoryInfo;
            FileInfo[] files = directory != null ? directory.GetFiles() : null;

            if ( files != null )
            {
                List<UltraListViewItem> items = new List<UltraListViewItem>(files.Length);

                foreach( FileInfo file in files )
                {
                    UltraListViewItem item = new UltraListViewItem( file.Name, null );
                    item.Tag = file;
                    items.Add( item );
                }

                this.lvwFiles.Items.AddRange( items.ToArray() );
            }
        }

        private void unbFolders_InitializeLocations(object sender, InitializeLocationsEventArgs e)
        {
            //  As each Locations collection is initialized, populate it with
            //  its parent location's child directories.
            DirectoryInfo directoryInfo = e.ParentLocation.Tag as DirectoryInfo;
            if ( directoryInfo != null )
            {
                DirectoryInfo[] directories = directoryInfo.GetDirectories();

                foreach( DirectoryInfo directory in directories )
                {
                    UltraNavigationBarLocation location = e.ParentLocation.Locations.Add( directory.Name );                    
                    location.Tag = directory;
                }
            }
        }
    }
}